{
    "command": "/etc/haproxy/haproxy_run.sh",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/haproxy_run.sh",
            "dest": "/etc/haproxy/haproxy_run.sh",
            "owner": "root",
            "perm": "0700"
        },
        {
            "source": "{{ container_config_directory }}/haproxy.cfg",
            "dest": "/etc/haproxy/haproxy.cfg",
            "owner": "root",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/services.d/",
            "dest": "/etc/haproxy/services.d",
            "owner": "root",
            "perm": "0700"
        },
        {
            "source": "{{ container_config_directory }}/haproxy.pem",
            "dest": "/etc/haproxy/haproxy.pem",
            "owner": "root",
            "perm": "0600",
            "optional": {{ (not kolla_enable_tls_external | bool) | string | lower }}
        }
    ]
}
