[provider]
name = OS Infra Provider
description = This provider uses OpenStack's own services (swift, cinder) as storage
id = {{ karbor_openstack_infra_id }}

plugin=karbor-volume-protection-plugin
plugin=karbor-image-protection-plugin
plugin=karbor-server-protection-plugin
bank=karbor-swift-bank-plugin

[swift_client]
swift_auth_url={{ keystone_internal_url }}/v3
swift_auth_version=3
swift_user=admin
swift_key={{ keystone_admin_password }}
swift_tenant_name=admin
swift_project_domain_id = {{ default_project_domain_id }}
swift_user_domain_id = {{ default_user_domain_id }}


[swift_bank_plugin]
lease_expire_window=120
lease_renew_window=100
lease_validity_window=100
