{
    "command": "barbican-worker",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/barbican.conf",
            "dest": "/etc/barbican/barbican.conf",
            "owner": "barbican",
            "perm": "0600"
        }{% if barbican_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ barbican_policy_file }}",
            "dest": "/etc/barbican/{{ barbican_policy_file }}",
            "owner": "barbican",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/barbican",
            "owner": "barbican:barbican"
        }
    ]
}
