{
    "command": "tacker-server --config-file /etc/tacker/tacker.conf",
    "config_files":[
        {
            "source": "{{ container_config_directory }}/tacker.conf",
            "dest": "/etc/tacker/tacker.conf",
            "owner": "tacker",
            "perm": "0600"
        }{% if tacker_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ tacker_policy_file }}",
            "dest": "/etc/tacker/{{ tacker_policy_file }}",
            "owner": "tacker",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/tacker",
            "owner": "tacker:tacker",
            "recurse": true
        }
    ]
}
