{
    "command": "/opt/cadvisor --port={{ prometheus_cadvisor_port }} --log_dir=/var/log/kolla/prometheus",
    "config_files": [],
    "permissions": [
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:prometheus",
            "recurse": true
        }
    ]
}
