{% set apache_cmd = 'apache2' if kolla_base_distro in ['ubuntu', 'debian'] else 'httpd' %}
{% set apache_dir = 'apache2/conf-enabled' if kolla_base_distro in ['ubuntu', 'debian'] else 'httpd/conf.d' %}
{
    "command": "{{ apache_cmd }} -DFOREGROUND",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/freezer.conf",
            "dest": "/etc/freezer/freezer.conf",
            "owner": "freezer",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/wsgi-freezer-api.conf",
            "dest": "/etc/{{ apache_dir }}/wsgi-freezer.conf",
            "owner": "freezer",
            "perm": "0600"
        }{% if freezer_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ freezer_policy_file }}",
            "dest": "/etc/freezer/{{ freezer_policy_file }}",
            "owner": "freezer",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/freezer",
            "owner": "freezer:freezer",
            "recurse": true
        }
    ]
}
