[DEFAULT]
debug = {{ cloudkitty_logging_debug }}

log_dir = /var/log/kolla/cloudkitty

{% if service_name == 'cloudkitty-api' %}
# Force cloudkitty-api.log or will use app.wsgi
log_file = /var/log/kolla/cloudkitty/cloudkitty-api.log
{% endif %}

transport_url = {{ rpc_transport_url }}

[database]
connection = mysql+pymysql://{{ cloudkitty_database_user }}:{{ cloudkitty_database_password }}@{{ cloudkitty_database_address }}/{{ cloudkitty_database_name }}
max_retries = -1

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ cloudkitty_keystone_user }}
password = {{ cloudkitty_keystone_password }}
region_name = {{ openstack_region_name }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[oslo_concurrency]
lock_path = /var/lib/cloudkitty/tmp

{% if cloudkitty_policy_file is defined %}
[oslo_policy]
policy_file = {{ cloudkitty_policy_file }}
{% endif %}

[collect]
collector = {{ cloudkitty_collector_backend }}
services = compute,image{% if enable_cinder | bool %},volume{% endif %},network.bw.out,network.bw.in,network.floating

[keystone_fetcher]
keystone_version = 3
auth_section = keystone_authtoken
region_name = {{ openstack_region_name }}

{% if cloudkitty_collector_backend == "gnocchi" %}
[gnocchi_collector]
auth_section = keystone_authtoken
region_name = {{ openstack_region_name }}
{% endif %}

[api]
host_ip = {{ api_interface_address }}
port = {{ cloudkitty_api_port }}

[orchestrator]
coordination_url = mysql://{{ cloudkitty_database_user }}:{{ cloudkitty_database_password }}@{{ cloudkitty_database_address }}/{{ cloudkitty_database_name }}

[storage]
backend = {{ cloudkitty_storage_backend }}
{% if cloudkitty_storage_backend == 'influxdb' %}
version = 2
{% endif %}
{% if cloudkitty_storage_backend == 'sqlalchemy' %}
version = 1
{% endif %}

{% if cloudkitty_storage_backend == 'influxdb' %}
[storage_influxdb]
database = {{ cloudkitty_influxdb_name }}
host = {{ influxdb_address }}
port = {{ influxdb_http_port }}

{% if cloudkitty_influxdb_retention_policy is defined %}
retention_policy = {{ cloudkitty_influxdb_retention_policy }}
{% endif %}

{% if cloudkitty_influxdb_use_ssl is defined %}
use_ssl = {{ cloudkitty_influxdb_use_ssl }}
{% endif %}

{% if cloudkitty_influxdb_insecure_connections is defined %}
insecure = {{ cloudkitty_influxdb_insecure_connections }}
{% endif %}

{% if cloudkitty_influxdb_cafile is defined %}
cafile = {{ cloudkitty_influxdb_cafile }}
{% endif %}

{% endif %}
