{
    "command": "blazar-api --config-file /etc/blazar/blazar.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/blazar.conf",
            "dest": "/etc/blazar/blazar.conf",
            "owner": "blazar",
            "perm": "0600"
        }{% if blazar_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ blazar_policy_file }}",
            "dest": "/etc/blazar/{{ blazar_policy_file }}",
            "owner": "blazar",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/blazar",
            "owner": "blazar:blazar",
            "recurse": true
        }
    ]
}
