# dhcp_agent.ini
[DEFAULT]
dnsmasq_config_file = /etc/neutron/dnsmasq.conf
enable_isolated_metadata = true
force_metadata = true
dnsmasq_dns_servers = {{ neutron_dnsmasq_dns_servers }}

{% if neutron_plugin_agent == 'vmware_dvs' %}
ovs_integration_bridge = {{ neutron_bridge_name }}
interface_driver = openvswitch
enable_metadata_network = True
dhcp_driver = vmware_nsx.plugins.dvs.dhcp.Dnsmasq
use_namespaces = True
ovs_use_veth = False
{% if vmware_dvs_dhcp_override_mac != '' %}
dhcp_override_mac = {{ vmware_dvs_dhcp_override_mac }}
{% endif %}
{% endif %}

{% if enable_opendaylight | bool %}
interface_driver = openvswitch
{% endif %}

[ovs]
ovsdb_connection = tcp:127.0.0.1:{{ ovsdb_port }}
