{
    "command": "karbor-protection --config-file /etc/karbor/karbor.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/karbor.conf",
            "dest": "/etc/karbor/karbor.conf",
            "owner": "karbor",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/providers.d/*",
            "dest": "/etc/karbor/providers.d/",
            "owner": "karbor",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/karbor",
            "owner": "karbor:karbor",
            "recurse": true
        }
    ]
}
