{% set cinder_cmd = 'apache2' if kolla_base_distro in ['ubuntu', 'debian'] else 'httpd' %}
{% set cinder_dir = 'apache2/conf-enabled' if kolla_base_distro in ['ubuntu', 'debian'] else 'httpd/conf.d' %}
{
    "command": "{{ cinder_cmd }} -DFOREGROUND",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/cinder.conf",
            "dest": "/etc/cinder/cinder.conf",
            "owner": "cinder",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/cinder-wsgi.conf",
            "dest": "/etc/{{ cinder_dir }}/cinder-wsgi.conf",
            "owner": "cinder",
            "perm": "0600"
        }{% if cinder_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ cinder_policy_file }}",
            "dest": "/etc/cinder/{{ cinder_policy_file }}",
            "owner": "cinder",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/lib/cinder",
            "owner": "cinder:cinder",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/cinder",
            "owner": "cinder:cinder",
            "recurse": true
        }
    ]
}
