{
    "command": "zun-compute --config-file /etc/zun/zun.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/zun.conf",
            "dest": "/etc/zun/zun.conf",
            "owner": "zun",
            "perm": "0600"
        }{% if zun_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ zun_policy_file }}",
            "dest": "/etc/zun/{{ zun_policy_file }}",
            "owner": "zun",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/zun",
            "owner": "zun:kolla",
            "recurse": true
        }
    ]
}
