{
    "command": "skydive agent --conf /etc/skydive/skydive.conf --listen={{ api_interface_address }}:{{ skydive_agents_port }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/skydive.conf",
            "dest": "/etc/skydive/skydive.conf",
            "owner": "skydive",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/skydive",
            "owner": "skydive:skydive",
            "recurse": true
        }
    ]
}
