{% if enable_opendaylight_legacy_netvirt_conntrack | bool %}
<netvirt-impl-config xmlns="urn:opendaylight:params:xml:ns:yang:netvirt:impl:config">
  <conntrack-enabled>
    true
  </conntrack-enabled>
</netvirt-impl-config>
{% endif %}
