{
    "command": "searchlight-api",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/searchlight.conf",
            "dest": "/etc/searchlight/searchlight.conf",
            "owner": "searchlight",
            "perm": "0600"
        }{% if searchlight_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ searchlight_policy_file }}",
            "dest": "/etc/searchlight/{{ searchlight_policy_file }}",
            "owner": "searchlight",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/searchlight",
            "owner": "searchlight:searchlight",
            "recurse": true
        }
    ]
}
