{
    "command": "/opt/zookeeper/bin/zkServer.sh start-foreground /etc/zookeeper/conf/zoo.cfg",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/myid",
            "dest": "/var/lib/zookeeper/data/myid",
            "owner": "zookeeper",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/zookeeper.cfg",
            "dest": "/etc/zookeeper/conf/zoo.cfg",
            "owner": "zookeeper",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/zookeeper",
            "owner": "zookeeper:zookeeper",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/zookeeper",
            "owner": "zookeeper:zookeeper",
            "recurse": true
        }
    ]
}
