{
    "command": "solum-worker --config-file /etc/solum/solum.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/solum.conf",
            "dest": "/etc/solum/solum.conf",
            "owner": "solum",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/solum",
            "owner": "solum:solum",
            "recurse": true
        }
    ]
}
