{% if enable_neutron_fwaas | bool %}
[fwaas]
enabled = True
{% if neutron_plugin_agent == 'vmware_nsxv' %}
driver = vmware_nsxv_edge
{% else %}
agent_version = v2
driver = iptables_v2

[service_providers]
service_provider = FIREWALL_V2:fwaas_db:neutron_fwaas.services.firewall.service_drivers.agents.agents.FirewallAgentDriver:default
{% endif %}
{% endif %}
