# Note (blallau): to manage Apache and WSGI log files
{% set fluentd_dir = 'td-agent' if kolla_base_distro in ['ubuntu', 'debian'] else 'fluentd' %}
<source>
  @type tail
  path /var/log/kolla/*/*-access.log,/var/log/kolla/*/*-error.log,/var/log/kolla/*/*_access.log,/var/log/kolla/*/*_error.log
  pos_file /var/run/{{ fluentd_dir }}/kolla-openstack-wsgi.pos
  tag kolla.*
  format /^(?<Payload>.*)$/
  enable_watch_timer false
</source>
