[DEFAULT]
debug = {{ freezer_logging_debug }}

log_dir = /var/log/kolla/freezer

{% if service_name == 'freezer-api' %}
bind_host = {{ api_interface_address }}
bind_port = {{ freezer_api_port }}
{% endif %}

{% if service_name == 'freezer-scheduler' %}
client_id = {{ inventory_hostname }}
jobs_dir = /etc/freezer/scheduler/conf.d

os_username = {{ openstack_auth.username }}
os_password = {{ openstack_auth.password }}
os_auth_url = {{ openstack_auth.auth_url }}/v3
os_project_name = {{ openstack_auth.project_name }}
os_project_domain_name = {{ openstack_auth.domain_name }}
os_user_domain_name = {{ openstack_auth.user_domain_name }}
{% endif %}

{% if service_name == 'freezer-api' %}
[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ freezer_keystone_user }}
password = {{ freezer_keystone_password }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

{% if freezer_policy_file is defined %}
[oslo_policy]
policy_file = {{ freezer_policy_file }}
{% endif %}

[oslo_middleware]
enable_proxy_headers_parsing = True

[paste_deploy]
config_file = /etc/freezer/freezer-paste.ini

[storage]
backend = elasticsearch
driver = elasticsearch

[elasticsearch]
hosts = {{ internal_protocol }}://{{ kolla_internal_fqdn }}:{{ elasticsearch_port }}
number_of_replicas = 0
index = freezer
{% endif %}
