{# Cron uses a PATH of /usr/bin:/bin by default, which does not include the #}
{# virtualenv in source images. #}
{% if keystone_install_type == 'source' %}
PATH=/var/lib/kolla/venv/bin:/usr/bin:/bin
{% endif %}

{% for cron_job in cron_jobs %}
{{ cron_job['min'] }} {{ cron_job['hour'] }} * * {{ cron_job['day'] }} /usr/bin/fernet-rotate.sh
{% endfor %}
