{
    "command": "/usr/sbin/qdrouterd",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/qdrouterd.conf",
            "dest": "/etc/qpid-dispatch/qdrouterd.conf",
            "owner": "qdrouterd",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/qdrouterd-sasl.conf",
            "dest": "/etc/sasl2/qdrouterd.conf",
            "owner": "qdrouterd",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/qdrouterd",
            "owner": "qdrouterd:qdrouterd",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/qdrouterd",
            "owner": "qdrouterd:qdrouterd",
            "recurse": true
        }
    ]
}
