{
    "command": "cyborg-api --config-file /etc/cyborg/cyborg.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/cyborg.conf",
            "dest": "/etc/cyborg/cyborg.conf",
            "owner": "cyborg",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/api-paste.ini",
            "dest": "/etc/cyborg/api-paste.ini",
            "owner": "cyborg",
            "perm": "0600"
        }{% if cyborg_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ cyborg_policy_file }}",
            "dest": "/etc/cyborg/{{ cyborg_policy_file }}",
            "owner": "cyborg",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/cyborg",
            "owner": "cyborg:cyborg",
            "recurse": true
        }
    ]
}
