<match *.**>
    @type copy
    <store>
       @type elasticsearch
       host {{ elasticsearch_address }}
       port {{ elasticsearch_port }}
       logstash_format true
       logstash_prefix {{ kibana_log_prefix }}
       flush_interval 15s
       reconnect_on_error true
       buffer_type file
       buffer_path /var/lib/fluentd/data/elasticsearch.buffer/openstack.*
    </store>
</match>
