### Skydive agent config file

auth:
  analyzer_username: {{ openstack_auth['username'] }}
  analyzer_password: {{ openstack_auth['password'] }}

logging:
  level: INFO
  backends:
    - file
  file:
    path: /var/log/kolla/skydive/skydive-agent.log

etcd:
  servers:
{% if enable_etcd | bool %}
{% for host in groups['etcd'] %}
    - http://{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ etcd_client_port }}
{% endfor %}
{% else %}
{% for host in groups['skydive-analyzer'] %}
  - http://{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ etcd_client_port }}
{% endfor %}
{% endif %}

analyzers:
{% for host in groups['skydive-analyzer'] %}
  - {{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ skydive_analyzer_port }}
{% endfor %}

agent:
  listen: {{ hostvars[inventory_hostname]['ansible_' + hostvars[inventory_hostname]['api_interface']]['ipv4']['address'] }}:{{ skydive_agents_port }}
  flow:
    probes:
      - gopacket
{% if neutron_plugin_agent in ['openvswitch', 'opendaylight'] %}
      - ovssflow
{% endif %}
  topology:
    probes:
      - netlink
      - netns
      - neutron
{% if neutron_plugin_agent in ['openvswitch', 'opendaylight'] %}
      - ovsdb
{% endif %}

    neutron:
      auth_url: {{ keystone_internal_url }}/v3
      username: {{ openstack_auth['username'] }}
      password: {{ openstack_auth['password'] }}
      tenant_name: {{ openstack_auth['project_name'] }}
      region_name: {{ openstack_region_name }}
      domain_name: Default
      endpoint_type: internal

netns:
  run_path: /host/run

flow:
  expire: 600
  update: 60

{% if neutron_plugin_agent in ['openvswitch', 'opendaylight'] %}
ovs:
  ovsdb: tcp://127.0.0.1:{{ ovsdb_port }}
  oflow:
    enable: true
{% endif %}
