[DEFAULT]

debug = {{ glance_logging_debug }}
log_file = /var/log/kolla/glance/glance-cache.log

image_cache_max_size = {{ glance_cache_max_size }}
image_cache_dir = /var/lib/glance/image-cache

auth_url = {{ keystone_admin_url }}
admin_password = {{ glance_keystone_password }}
admin_user = {{ glance_keystone_user }}
admin_tenant_name = {{ default_project_domain_id }}

{% if glance_backend_file | bool %}
filesystem_store_datadir = /var/lib/glance/images/
{% endif %}
