{
    "command": "monasca-notification --config-file /etc/monasca/notification.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/notification.conf",
            "dest": "/etc/monasca/notification.conf",
            "owner": "monasca",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/notification_templates/*",
            "dest": "/etc/monasca/",
            "owner": "monasca",
            "perm": "0600",
            "optional": true
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/monasca",
            "owner": "monasca:kolla",
            "recurse": true
        }
    ]
}
