[DEFAULT]
debug = {{ solum_logging_debug }}
log_dir = /var/log/kolla/solum
transport_url = {{ rpc_transport_url }}

{% if service_name == 'solum-api' %}
bind_host = {{ api_interface_address }}
bind_port = {{ solum_application_deployment_port }}
{% endif %}

[api]
image_format = vm
port = {{ solum_application_deployment_port }}
workers = {{ openstack_service_workers }}

[conductor]
topic = solum-conductor

[deployer]
growth_factor = 1.1
wait_interval = 1
max_attempts = 2000
handler = heat
topic = solum-deployer

[worker]
proj_dir = /solum
handler = shell
topic = solum-worker
task_log_dir = /var/log/kolla/solum/worker
image_storage = glance
docker_build_timeout = 1800
lp_operator_tenant_name = service
lp_operator_password = {{ solum_keystone_password }}
lp_operator_user = {{ solum_keystone_user }}

[builder]
port = {{ solum_image_builder_public_endpoint }}
host = {{ ansible_hostname }}_{{ item }}

[database]
connection = mysql+pymysql://{{ solum_database_user }}:{{ solum_database_password }}@{{ solum_database_address }}/{{ solum_database_name }}
max_retries = -1

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ solum_keystone_user }}
password = {{ solum_keystone_password }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
