Main:
  hostname: {{ ansible_hostname }}
  check_freq: {{ monasca_agent_check_frequency }}
  forwarder_url: http://127.0.0.1:{{ monasca_agent_forwarder_port }}

Logging:
  log_level: {{ 'DEBUG' if monasca_logging_debug else 'INFO' }}
  collector_log_file: /var/log/kolla/monasca/agent-collector.log
  enable_logrotate: False
