{
    "command": "swift-container-server /etc/swift/container-server.conf --verbose",
    "config_files": [
        {
            "source": "/var/lib/kolla/swift/container.ring.gz",
            "dest": "/etc/swift/container.ring.gz",
            "owner": "swift",
            "perm": "0640"
        },
        {
            "source": "{{ container_config_directory }}/swift.conf",
            "dest": "/etc/swift/swift.conf",
            "owner": "swift",
            "perm": "0640"
        },
        {
            "source": "{{ container_config_directory }}/container-replication-server.conf",
            "dest": "/etc/swift/container-server.conf",
            "owner": "swift",
            "perm": "0640"
        },
        {
            "source": "{{ container_config_directory }}/policy.json",
            "dest": "/etc/swift/policy.json",
            "owner": "swift",
            "perm": "0600",
            "optional": true
        }
    ]
}
