[DEFAULT]
debug = {{ vitrage_logging_debug }}
log_dir = /var/log/kolla/vitrage

{% if service_name == 'vitrage-api' %}
# Force vitrage-api.log or will use app.wsgi
log_file = /var/log/kolla/vitrage/vitrage-api.log
{% endif %}

{% if vitrage_notifiers %}
notifiers = {{ vitrage_notifiers|map(attribute='name')|join(',') }}
{% endif %}

transport_url = {{ rpc_transport_url }}

[api]
host = {{ api_interface_address }}
port = {{ vitrage_api_port }}
workers = {{ openstack_service_workers }}

[database]
connection = mysql+pymysql://{{ vitrage_database_user }}:{{ vitrage_database_password }}@{{ vitrage_database_address }}/{{ vitrage_database_name }}

{% if vitrage_datasources %}
[datasources]
types = {{ vitrage_datasources|map(attribute='name')|join(',') }}
{% endif %}

[machine_learning]
plugins = jaccard_correlation

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ vitrage_keystone_user }}
password = {{ vitrage_keystone_password }}
service_token_roles_required = True

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[service_credentials]
auth_url = {{ keystone_internal_url }}/v3
region_name = {{ openstack_region_name }}
auth_type = password
project_domain_id = default
user_domain_id = default
project_name = admin
password = {{ vitrage_keystone_password }}
username = {{ vitrage_keystone_user }}
interface = internal

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
topics = notifications,vitrage_notifications
driver = messagingv2

[oslo_concurrency]
lock_path = /var/lib/vitrage/tmp

[oslo_middleware]
enable_proxy_headers_parsing = True

{% if vitrage_policy_file is defined %}
[oslo_policy]
policy_file = {{ vitrage_policy_file }}
{% endif %}

{% if enable_osprofiler | bool %}
[profiler]
enabled = true
trace_sqlalchemy = true
hmac_keys = {{ osprofiler_secret }}
connection_string = {{ osprofiler_backend_connection_string }}
{% endif %}

{% if enable_vitrage_prometheus_datasource | bool %}
[prometheus]
config_file = /etc/vitrage/prometheus_conf.yaml
{% endif %}
