[DEFAULT]
debug = {{ karbor_logging_debug }}
log_dir = /var/log/kolla/karbor
transport_url = {{ rpc_transport_url }}

{% if service_name == 'karbor-api' %}
osapi_karbor_listen = {{ api_interface_address }}
osapi_karbor_listen_port = {{ karbor_api_port }}
osapi_karbor_workers = {{ openstack_service_workers }}
{% endif %}

[database]
connection = mysql+pymysql://{{ karbor_database_user }}:{{ karbor_database_password }}@{{ karbor_database_address }}/{{ karbor_database_name }}
max_retries = -1

[trustee]
user_domain_id = {{ default_user_domain_id }}
username = {{ karbor_keystone_user }}
password = {{ karbor_keystone_password }}
auth_url = {{ keystone_admin_url }}
auth_type = password

[clients_keystone]
auth_uri = {{ keystone_internal_url }}

[karbor_client]
version = 1
service_type = data-protect
service_name = karbor
region_id = {{ openstack_region_name }}

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
project_domain_name = {{ default_project_domain_name }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ karbor_keystone_user }}
password = {{ karbor_keystone_password }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}

[oslo_middleware]
enable_proxy_headers_parsing = True
