{% if enable_neutron_lbaas | bool %}
[service_providers]
{% if enable_octavia | bool %}
service_provider = LOADBALANCERV2:Octavia:neutron_lbaas.drivers.octavia.driver.OctaviaDriver:default
{% elif neutron_plugin_agent == 'vmware_nsxv' %}
service_provider = LOADBALANCERV2:VMWareEdge:neutron_lbaas.drivers.vmware.edge_driver_v2.EdgeLoadBalancerDriverV2:default
{% else %}
service_provider = LOADBALANCERV2:Haproxy:neutron_lbaas.drivers.haproxy.plugin_driver.HaproxyOnHostPluginDriver:default
{% endif %}

[service_auth]
auth_url = {{ keystone_admin_url }}/v3
admin_tenant_name = service
admin_user = neutron
admin_password = {{ neutron_keystone_password }}
auth_version = 3
region = {{ openstack_region_name }}
endpoint_type = internal
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}

{% endif %}
