################################################################################
#
#    Licensed to the Apache Software Foundation (ASF) under one or more
#    contributor license agreements.  See the NOTICE file distributed with
#    this work for additional information regarding copyright ownership.
#    The ASF licenses this file to You under the Apache License, Version 2.0
#    (the "License"); you may not use this file except in compliance with
#    the License.  You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
#
################################################################################

featuresRepositories = mvn:org.apache.karaf.features/standard/${karaf.version}/xml/features, \
    mvn:org.apache.karaf.features/enterprise/${karaf.version}/xml/features, \
    mvn:org.ops4j.pax.web/pax-web-features/3.2.9/xml/features, \
    mvn:org.apache.karaf.features/spring/${karaf.version}/xml/features, \
    mvn:org.opendaylight.integration/features-integration-index/${project.version}/xml/features

featuresBoot=config,standard,region,package,kar,ssh,management{% if not opendaylight_features == '' %},{% endif %}{{ opendaylight_features }}

featuresBootAsynchronous=false
