{
    "command": "start-ovsdb-server  {% if enable_onos | bool %} 0.0.0.0 {% else %} 127.0.0.1 {% endif %}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/start-ovsdb-server",
            "dest": "/usr/local/bin/start-ovsdb-server",
            "owner": "root",
            "perm": "0655"
        }
    ]
}
