[DEFAULT]
kuryr_uri = {{ internal_protocol }}://{{ api_interface_address }}:{{ kuryr_port }}
debug = {{ kuryr_logging_debug }}
log_dir = /var/log/kolla/kuryr

capability_scope = global
bindir = /var/lib/kolla/venv/libexec/kuryr

[binding]
default_driver = kuryr.lib.binding.drivers.veth

[neutron]
auth_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
endpoint_type = internal
project_domain_name = {{ default_project_domain_name }}
project_name = service
user_domain_name = {{ default_user_domain_name }}
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
password = {{ kuryr_keystone_password }}
username = {{ kuryr_keystone_user }}

{% if kuryr_policy_file is defined %}
[oslo_policy]
policy_file = {{ kuryr_policy_file }}
{% endif %}
