{% set pxe_dir = ('/tftpboot/grub' if kolla_base_distro in ['ubuntu', 'debian'] else '/tftpboot/EFI/centos') if enable_ironic_pxe_uefi | bool else '/tftpboot/pxelinux.cfg' %}
{% set pxe_cfg = 'grub.cfg' if enable_ironic_pxe_uefi | bool else 'default' %}

{
    "command": "/usr/sbin/in.tftpd --verbose --foreground --user root --address 0.0.0.0:69 --map-file /map-file /tftpboot",
    "config_files": [
{% if not enable_ironic_ipxe | bool and groups['ironic-inspector'] | length > 0 %}
{% if not enable_ironic_pxe_uefi | bool %}
        {
            "source": "{{ container_config_directory }}/ironic-agent.kernel",
            "dest": "/tftpboot/ironic-agent.kernel",
            "owner": "root",
            "perm": "0644"
        },
        {
            "source": "{{ container_config_directory }}/ironic-agent.initramfs",
            "dest": "/tftpboot/ironic-agent.initramfs",
            "owner": "root",
            "perm": "0644"
        },
{% endif %}
        {
            "source": "{{ container_config_directory }}/default",
            "dest": "{{ pxe_dir }}/{{ pxe_cfg }}",
            "owner": "root",
            "perm": "0644"
        }
{% endif %}
    ],
    "permissions": [
        {
            "path": "{{ pxe_dir }}",
            "owner": "ironic:ironic",
            "recurse": true
        }
    ]
}
