{% set freezer_log_dir = '/var/log/kolla/freezer' %}
{% set python_path = '/usr/lib/python2.7/site-packages' if freezer_install_type == 'binary' else '/var/lib/kolla/venv/lib/python2.7/site-packages' %}
Listen {{ api_interface_address }}:{{ freezer_api_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off

<VirtualHost *:{{ freezer_api_port }}>
    WSGIDaemonProcess freezer-api processes={{ openstack_service_workers }} threads=1 user=freezer display-name=%{GROUP}
    WSGIProcessGroup freezer-api
    WSGIApplicationGroup %{GLOBAL}
    WSGIScriptAlias / {{ python_path }}/freezer_api/cmd/wsgi.py

    ErrorLog {{ freezer_log_dir }}/freezer-api.log
    LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
    CustomLog {{ freezer_log_dir }}/freezer-api_access.log logformat
    LogLevel info

    <Directory {{ python_path }}/freezer_api>
      Options Indexes FollowSymLinks MultiViews
      Require all granted
      AllowOverride None
      Order allow,deny
      allow from all
      LimitRequestBody 102400
    </Directory>
</VirtualHost>
