{% if gnocchi_install_type == 'binary' %}
    {% set python_path = '/usr/lib/python3/dist-packages' if kolla_base_distro == 'ubuntu' else '/usr/lib/python2.7/site-packages' %}
{% else %}
    {% set python_path = '/var/lib/kolla/venv/lib/python2.7/site-packages' %}
{% endif %}
{% set wsgi_path = '/usr/bin' if gnocchi_install_type == 'binary' else '/var/lib/kolla/venv/bin' %}
Listen {{ api_interface_address }}:{{ gnocchi_api_listen_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off

<VirtualHost *:{{ gnocchi_api_listen_port }}>

  ErrorLog "/var/log/kolla/gnocchi/gnocchi-api-error.log"
  LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
  CustomLog "/var/log/kolla/gnocchi/gnocchi-api-access.log" logformat
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess gnocchi group=gnocchi processes={{ openstack_service_workers }} threads=1 user=gnocchi python-path={{ python_path }}
  WSGIProcessGroup gnocchi
  WSGIScriptAlias / "{{ wsgi_path }}/gnocchi-api"

  <Directory "{{ wsgi_path }}">
        Require all granted
  </Directory>

</VirtualHost>
