NFS_CORE_PARAM {
    Protocols = 4;
    Enable_NLM = false;
    Enable_RQUOTA = false;
    Enable_UDP = false;
}

NFS_KRB5 {
    Active_krb5 = false;
}

EXPORT
{
	Export_id=1;

	Path = "/";

	Pseudo = /cephfs;

	Access_Type = RW;

	Protocols = 4;

	Transports = TCP;

	FSAL {
		Name = CEPH;
	}
}

LOG {
        Facility {
                name = FILE;
                destination = "/var/log/kolla/ceph/ceph-nfs.log";
                enable = active;
        }
}
