[DEFAULT]
debug = {{ openstack_logging_debug }}
control_exchange = neutron
rpc_backend = rabbit
log_dir = C:\OpenStack\Log
log_file = neutron-hyperv-agent.log
transport_url = {{ rpc_transport_url }}

[AGENT]
polling_interval = 2
physical_network_vswitch_mappings = *:{{ vswitch_name }}
enable_metrics_collection = false
enable_qos_extension = false

[SECURITYGROUP]
firewall_driver = hyperv
enable_security_group = true

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
