[DEFAULT]
log_file = monasca-log-api.log
log_dir = /var/log/kolla/monasca
debug = {{ monasca_logging_debug }}

[service]
region = {{ openstack_region_name }}
# Increase the maximum payload size to slightly above the default Fluentd chunk size (8MB)
max_log_size = 10485760

[kafka_healthcheck]
kafka_topics = {{ monasca_raw_logs_topic }}
kafka_url = {{ monasca_kafka_servers }}

[log_publisher]
topics = {{ monasca_raw_logs_topic }}
kafka_url = {{ monasca_kafka_servers }}

[monitoring]
statsd_buffer = 30
statsd_port = {{ monasca_agent_statsd_port }}

[roles_middleware]
path = /v2.0/log, /v3.0/logs
default_roles = {{ monasca_default_authorized_roles|join(', ') }}
agent_roles = {{ monasca_agent_authorized_roles|join(', ') }}
delegate_roles = {{ monasca_delegate_authorized_roles|join(', ') }}

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_id =  {{ default_project_domain_id }}
user_domain_id =  {{ default_user_domain_id }}
project_name = service
username = {{ monasca_keystone_user }}
password = {{ monasca_keystone_password }}
service_token_roles_required=True

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {{ monasca_memcached_servers }}
