{% if enable_neutron_vpnaas | bool %}
[service_providers]
{% if neutron_plugin_agent == 'vmware_nsxv' %}
service_provider = VPN:vmware:vmware_nsx.services.vpnaas.nsxv.ipsec_driver.NSXvIPsecVpnDriver:default
{% else %}
service_provider = VPN:openswan:neutron_vpnaas.services.vpn.service_drivers.ipsec.IPsecVPNDriver:default
{% endif %}
{% endif %}
