{
    "command": "/usr/bin/ganesha.nfsd -F -f /etc/ganesha/ganesha.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ganesha.conf",
            "dest": "/etc/ganesha/ganesha.conf",
            "owner": "ceph",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "ceph",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.client.admin.keyring",
            "dest": "/etc/ceph/ceph.client.admin.keyring",
            "owner": "ceph",
            "perm": "0600",
            "optional": true
        }
    ]
}
