{
    "command": "/opt/storm/bin/storm jar /monasca-thresh-source/monasca-thresh-*/thresh/target/monasca-thresh-*-SNAPSHOT-shaded.jar -Djava.io.tmpdir=/var/lib/monasca-thresh/data monasca.thresh.ThresholdingEngine /etc/monasca/thresh-config.yml monasca-thresh local",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/thresh-config.yml",
            "dest": "/etc/monasca/thresh-config.yml",
            "owner": "monasca",
            "perm": "0600"
        },
        {
            "source": "/var/lib/kolla/config_files/storm.yml",
            "dest": "/opt/storm/conf/storm.yaml",
            "owner": "monasca",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/monasca",
            "owner": "monasca:kolla",
            "recurse": true
        },
        {
            "path": "/var/lib/monasca-thresh",
            "owner": "monasca:kolla",
            "recurse": true
        }
    ]
}
