storm.local.dir: "/var/lib/monasca-thresh/data"
storm.log.dir: "/var/log/kolla/storm"
storm.workers.artifacts.dir: "/var/lib/monasca-thresh/worker-artifacts"
nimbus.seeds: [{{ monasca_storm_nimbus_servers }}]
storm.zookeeper.port: {{ zookeeper_client_port }}
storm.zookeeper.servers:
{% for host in groups['zookeeper'] %}
  - "{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}"
{% endfor %}
