global:
  resolve_timeout: 5m
  smtp_require_tls: true
route:
  receiver: default-receiver
  group_wait: 10s
  group_interval: 5m
  repeat_interval: 3h
receivers:
  - name: default-receiver
{% if enable_vitrage | bool and enable_vitrage_prometheus_datasource | bool %}
    webhook_configs:
      - send_resolved: true
        url: '{{ public_protocol }}://{{ kolla_external_fqdn }}:{{ vitrage_api_port }}/v1/event'
        http_config:
          basic_auth:
            username: '{{ keystone_admin_user }}'
            password: '{{ keystone_admin_password }}'
{% endif %}
templates: []
