{% set python_path = '/usr/lib/python2.7/site-packages' if panko_install_type == 'binary' else '/var/lib/kolla/venv/lib/python2.7/site-packages' %}
{% set binary_path = '/usr/bin' if panko_install_type == 'binary' else '/var/lib/kolla/venv/bin' %}
Listen {{ api_interface_address }}:{{ panko_api_port }}

ServerSignature Off
ServerTokens Prod
TraceEnable off

<Directory "{{ binary_path }}">
    <FilesMatch "^panko-api$">
        Require all granted
    </FilesMatch>
</Directory>

<VirtualHost *:{{ panko_api_port }}>

  ErrorLog "/var/log/kolla/panko/panko-api-error.log"
  LogFormat "%{X-Forwarded-For}i %l %u %t \"%r\" %>s %b %D \"%{Referer}i\" \"%{User-Agent}i\"" logformat
  CustomLog "/var/log/kolla/panko/panko-api-access.log" logformat
  WSGIApplicationGroup %{GLOBAL}
  WSGIDaemonProcess panko group=panko processes={{ openstack_service_workers }} threads=1 user=panko python-path={{ python_path }}
  WSGIProcessGroup panko
  WSGIScriptAlias / "{{ binary_path }}/panko-api"

</VirtualHost>
