org.osgi.framework.system.packages.extra=org.apache.karaf.branding,sun.reflect,sun.reflect.misc,sun.misc,sun.nio.ch,com.sun.media.sound

osgi.hook.configurators.include=org.eclipse.virgo.kernel.equinox.extensions.hooks.ExtensionsHookConfigurator


org.eclipse.gemini.web.tomcat.config.path=configuration/tomcat-server.xml
org.apache.tomcat.util.buf.UDecoder.ALLOW_ENCODED_SLASH=true

karaf.framework=equinox

karaf.delay.console=true

org.apache.karaf.security.providers = org.bouncycastle.jce.provider.BouncyCastleProvider

org.apache.aries.blueprint.preemptiveShutdown=false

netconf.config.persister.active=1

netconf.config.persister.1.storageAdapterClass=org.opendaylight.controller.config.persist.storage.file.xml.XmlFileStorageAdapter
netconf.config.persister.1.properties.fileStorage=etc/opendaylight/current/controller.currentconfig.xml
netconf.config.persister.1.properties.numberOfBackups=1

logback.configurationFile=configuration/logback.xml

container.profile = Container

connection.scheme = ANY_CONTROLLER_ONE_MASTER

ovsdb.l3.arp.responder.disabled=no

secureChannelEnabled=false
controllerKeyStore=
controllerKeyStorePassword=
controllerTrustStore=
controllerTrustStorePassword=

enableStrongPasswordCheck = false

java.util.logging.config.file=configuration/tomcat-logging.properties

hosttracker.keyscheme=IP

lisp.mappingMerge = false

lisp.smr = true

lisp.elpPolicy = default
