#include "/etc/rndc.key";
options {
        default-key "rndc-key";
        default-server {{ hostvars[inventory_hostname]['ansible_' + hostvars[inventory_hostname]['api_interface']]['ipv4']['address'] }};
        default-port {{ designate_rndc_port }};
};
