[DEFAULT]
debug = {{ tacker_logging_debug }}
log_dir = /var/log/kolla/tacker

transport_url = {{ rpc_transport_url }}

bind_host = {{ api_interface_address }}
bind_port = {{ tacker_server_port }}
api_workers = {{ openstack_service_workers }}
service_plugins = nfvo,vnfm

[nfvo]
vim_drivers = openstack

[openstack_vim]
stack_retries = 60
stack_retry_wait = 10

{% if enable_barbican | bool %}
[vim_keys]
use_barbican = True
{% endif %}

[tacker]
monitor_driver = ping,http_ping
alarm_monitor_driver = ceilometer

[database]
connection = mysql+pymysql://{{ tacker_database_user }}:{{ tacker_database_password }}@{{ tacker_database_address }}/{{ tacker_database_name }}
max_retries = -1

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_name = {{ default_project_domain_id }}
user_domain_name = {{ default_user_domain_id }}
project_name = service
username = {{ tacker_keystone_user }}
password = {{ tacker_keystone_password }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[alarm_auth]
username = {{ tacker_keystone_user }}
password = {{ tacker_keystone_password }}
project_name = service
url = {{ keystone_admin_url }}

[ceilometer]
host = {{ api_interface_address }}
port = {{ tacker_server_port }}


[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
{% if enable_ceilometer | bool %}
driver = messagingv2
topics = notifications
{% else %}
driver = noop
{% endif %}

{% if tacker_policy_file is defined %}
[oslo_policy]
policy_file = {{ tacker_policy_file }}
{% endif %}
