{% if neutron_plugin_agent == 'vmware_nsxv' %}
[nsxv]
user = {{ vmware_nsxv_user }}
password = {{ vmware_nsxv_password }}
manager_uri = {{ vmware_nsxv_manager_uri }}
insecure = {{ vmware_nsxv_insecure }}
cluster_moid = {{ vmware_nsxv_cluster_moid }}
datacenter_moid = {{ vmware_nsxv_datacenter_moid }}
resource_pool_id = {{ vmware_nsxv_resource_pool_id }}
datastore_id = {{ vmware_nsxv_datastore_id }}
external_network = {{ vmware_nsxv_external_network }}
vdn_scope_id = {{ vmware_nsxv_vdn_scope_id }}
dvs_id = {{ vmware_nsxv_dvs_id }}
backup_edge_pool = {{ vmware_nsxv_backup_edge_pool }}
spoofguard_enabled = {{ vmware_nsxv_spoofguard_enabled }}
metadata_initializer = {{ vmware_nsxv_metadata_initializer }}
edge_ha = {{ vmware_nsxv_edge_ha }}
{% elif neutron_plugin_agent == 'vmware_nsxv3' %}
[nsx_v3]
metadata_proxy = {{ nsxv3_metadata_proxy }}
dhcp_profile = {{ nsxv3_dhcp_profile }}
native_dhcp_metadata = {{ nsxv3_native_dhcp_metadata }}
nsx_api_password = {{ nsxv3_api_password }}
nsx_api_user = {{ nsxv3_api_user }}
nsx_api_managers = {{ nsxv3_api_managers }}
default_tier0_router = {{ nsxv3_default_tier0_router }}
default_vlan_tz = {{ nsxv3_default_vlan_tz }}
default_overlay_tz = {{ nsxv3_default_overlay_tz }}
{% elif neutron_plugin_agent == 'vmware_dvs' %}
[dvs]
host_ip = {{ vmware_dvs_host_ip }}
host_port = {{ vmware_dvs_host_port }}
host_username = {{ vmware_dvs_host_username }}
host_password = {{ vmware_dvs_host_password }}
task_poll_interval = 0.5
insecure = {{ vmware_dvs_insecure }}
api_retry_count = 10
dvs_name = {{ vmware_dvs_dvs_name }}
{% endif %}
