{
    "command": "ceilometer-polling --polling-namespaces central",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ceilometer.conf",
            "dest": "/etc/ceilometer/ceilometer.conf",
            "owner": "ceilometer",
            "perm": "0600"
        }{% if ceilometer_polling_file_path is defined %},
        {
            "source": "{{ container_config_directory }}/polling.yaml",
            "dest": "/etc/ceilometer/polling.yaml",
            "owner": "ceilometer",
            "perm": "0600"
        }{% endif %}{% if ceilometer_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ ceilometer_policy_file }}",
            "dest": "/etc/ceilometer/{{ ceilometer_policy_file }}",
            "owner": "ceilometer",
            "perm": "0600"
        }{% endif %},
        {
            "source": "{{ container_config_directory }}/pipeline.yaml",
            "dest": "/etc/ceilometer/pipeline.yaml",
            "owner": "ceilometer",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/ceilometer",
            "owner": "ceilometer:ceilometer",
            "recurse": true
        }
    ]
}
