[DEFAULT]
# Enable all fake hardware types and interfaces.
enabled_hardware_types = fake-hardware
enabled_boot_interfaces = fake
enabled_console_interfaces = ipmitool-socat,no-console
enabled_deploy_interfaces = fake
enabled_inspect_interfaces = inspector,no-inspect
enabled_management_interfaces = fake
enabled_network_interfaces = noop,flat,neutron
default_network_interface = neutron
enabled_power_interfaces = fake
enabled_raid_interfaces = agent,no-raid
default_raid_interface = no-raid
enabled_rescue_interfaces = fake
enabled_vendor_interfaces = no-vendor

[neutron]
cleaning_network = public1
provisioning_network = public1
