{
    "command": "/opt/prometheus/prometheus -config.file /etc/prometheus/prometheus.yml -web.listen-address {{ api_interface_address }}:{{ prometheus_port }} -web.external-url={{ internal_protocol }}://{{ kolla_internal_fqdn }}:{{ prometheus_port }} -log.format logger:stdout -storage.local.path /var/lib/prometheus{% if prometheus_cmdline_extras %} {{ prometheus_cmdline_extras }}{% endif %}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/prometheus.yml",
            "dest": "/etc/prometheus/prometheus.yml",
            "owner": "prometheus",
            "perm": "0600"
        }
{% if enable_prometheus_alertmanager %}
        ,{
            "source": "{{ container_config_directory }}/*.rules",
            "dest": "/etc/prometheus/",
            "optional": true,
            "owner": "prometheus",
            "perm": "0600"
        }
{% endif %}
    ],
    "permissions": [
        {
            "path": "/data",
            "owner": "prometheus:kolla",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:kolla",
            "recurse": true
        }
    ]
}
