{
    "command": "/opt/logstash/bin/logstash --log-in-json --log /var/log/kolla/logstash/monasca-log-persister.log -f /etc/logstash/conf.d/log-persister.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/log-persister.conf",
            "dest": "/etc/logstash/conf.d/log-persister.conf",
            "owner": "logstash",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/elasticsearch-template.json",
            "dest": "/etc/logstash/elasticsearch-template.json",
            "owner": "logstash",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/logstash",
            "owner": "logstash:kolla",
            "recurse": true
        }
    ]
}
