[DEFAULT]
log_file = monasca-notification.log
log_dir = /var/log/kolla/monasca
debug = {{ monasca_logging_debug }}

[kafka]
url = {{ monasca_kafka_servers }}
alarm_topic = {{ monasca_alarm_state_transitions_topic }}
notification_topic = {{ monasca_alarm_notifications_topic }}
notification_retry_topic = {{ monasca_alarm_notifications_retry_topic }}
periodic = {{ monasca_periodic_notifications_period }}:{{ monasca_periodic_notifications_topic }}

[mysql]
host = {{ monasca_database_address }}
port = {{ monasca_database_port }}
user = {{ monasca_database_user }}
passwd = {{ monasca_database_password }}
db = {{ monasca_database_name }}

[statsd]
port = {{ monasca_agent_statsd_port }}

[zookeeper]
url = {{ monasca_zookeeper_servers }}
