{
    "command": "/opt/storm/bin/storm nimbus",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/storm.yml",
            "dest": "/opt/storm/conf/storm.yaml",
            "owner": "storm",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/storm",
            "owner": "storm:storm",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/storm",
            "owner": "storm:storm",
            "recurse": true
        }
    ]
}
