NOVA_API_DB={{ nova_api_database_name }}
NOVA_API_USER={{ nova_api_database_user }}
NOVA_API_PASS={{ nova_api_database_password }}
NOVA_API_DB_HOST={{ nova_api_database_host }}
PLACEMENT_DB={{ placement_database_name }}
PLACEMENT_USER={{ placement_database_user }}
PLACEMENT_PASS={{ placement_database_password }}
PLACEMENT_DB_HOST={{ placement_database_host }}
