{
    "command": "trove-api --config-file=/etc/trove/trove.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/trove.conf",
            "dest": "/etc/trove/trove.conf",
            "owner": "trove",
            "perm": "0600"
    }{% if trove_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ trove_policy_file }}",
            "dest": "/etc/trove/{{ trove_policy_file }}",
            "owner": "trove",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/trove",
            "owner": "trove:trove",
            "recurse": true
        }
    ]
}
