{
    "command": "/opt/mysqld_exporter/mysqld_exporter --config.my-cnf /etc/prometheus/my.cnf --web.listen-address {{ api_interface_address }}:{{ prometheus_mysqld_exporter_port }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/my.cnf",
            "dest": "/etc/prometheus/my.cnf",
            "owner": "prometheus",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:kolla",
            "recurse": true
        }
    ]
}
