{
    "command": "designate-mdns --config-file /etc/designate/designate.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/designate.conf",
            "dest": "/etc/designate/designate.conf",
            "owner": "designate",
            "perm": "0600"
        }{% if designate_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ designate_policy_file }}",
            "dest": "/etc/designate/{{ designate_policy_file }}",
            "owner": "designate",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/designate",
            "owner": "designate:designate",
            "recurse": true
        }
    ]
}
