{
    "command": "/usr/bin/ceph-mgr -f -i {{ inventory_hostname }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "ceph",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.mgr.{{ inventory_hostname }}.keyring",
            "dest": "/var/lib/ceph/mgr/ceph-{{ inventory_hostname }}/keyring",
            "owner": "ceph",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.client.admin.keyring",
            "dest": "/etc/ceph/ceph.client.admin.keyring",
            "owner": "ceph",
            "perm": "0600"
        }
    ]
}
