<match syslog.{{ syslog_swift_facility }}.**>
  @type copy
  <store>
    @type file
    path /var/log/kolla/swift/swift_latest.*.log
    utc
    append true
    compress gzip
  </store>
{% if log_direct_to_elasticsearch %}
  <store>
       type elasticsearch
       host {{ elasticsearch_address }}
       port {{ elasticsearch_port }}
       logstash_format true
       logstash_prefix {{ kibana_log_prefix }}
       flush_interval 15s
       reconnect_on_error true
       buffer_type file
       buffer_path /var/lib/fluentd/data/elasticsearch.buffer/{{ syslog_swift_facility }}.*
  </store>
{% elif enable_monasca | bool %}
    type copy
    <store>
       @type monasca
       keystone_url {{ keystone_internal_url }}
       monasca_log_api {{ internal_protocol }}://{{ kolla_internal_fqdn }}:{{ monasca_log_api_port }}
       monasca_log_api_version v3.0
       username {{ monasca_agent_user }}
       password {{ monasca_agent_password }}
       domain_id default
       project_name {{ monasca_control_plane_project }}
       message_field_name Payload
    </store>
{% endif %}
</match>

<match syslog.{{ syslog_haproxy_facility }}.**>
  @type copy
  <store>
    @type file
    path /var/log/kolla/haproxy/haproxy_latest.*.log
    output_tag false
    output_time false
    utc
    append true
    compress gzip
  </store>
{% if log_direct_to_elasticsearch %}
  <store>
       type elasticsearch
       host {{ elasticsearch_address }}
       port {{ elasticsearch_port }}
       logstash_format true
       logstash_prefix {{ kibana_log_prefix }}
       flush_interval 15s
       reconnect_on_error true
       buffer_type file
       buffer_path /var/lib/fluentd/data/elasticsearch.buffer/{{ syslog_haproxy_facility }}.*
  </store>
{% elif enable_monasca | bool %}
    type copy
    <store>
       @type monasca
       keystone_url {{ keystone_internal_url }}
       monasca_log_api {{ internal_protocol }}://{{ kolla_internal_fqdn }}:{{ monasca_log_api_port }}
       monasca_log_api_version v3.0
       username {{ monasca_agent_user }}
       password {{ monasca_agent_password }}
       domain_id default
       project_name {{ monasca_control_plane_project }}
       message_field_name Payload
    </store>
{% endif %}
</match>
