module-shards = [
    {
        name = "default"
        shards = [
            {
                name="default"
                replicas = [
                    {% for host in groups['opendaylight'] %}
                    "{{ hostvars[host]['ansible_hostname'] }}"{% if not loop.last %},
                    {% endif %}
                    {% endfor %}
                ]
            }
        ]
    },
    {
        name = "topology"
        shards = [
            {
                name="topology"
                replicas = [
                    {% for host in groups['opendaylight'] %}
                    "{{ hostvars[host]['ansible_hostname'] }}"{% if not loop.last %},
                    {% endif %}
                    {% endfor %}
                ]
            }
        ]
    },
    {
        name = "inventory"
        shards = [
            {
                name="inventory"
                replicas = [
                    {% for host in groups['opendaylight'] %}
                    "{{ hostvars[host]['ansible_hostname'] }}"{% if not loop.last %},
                    {% endif %}
                    {% endfor %}
                ]
            }
        ]
    },
         {
             name = "toaster"
             shards = [
                 {
                     name="toaster"
                     replicas = [
                        {% for host in groups['opendaylight'] %}
                        "{{ hostvars[host]['ansible_hostname'] }}"{% if not loop.last %},
                        {% endif %}
                        {% endfor %}
                     ]
                 }
             ]
         }

]
