{
    "command": "false",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/my.cnf",
            "dest": "/etc/mysql/my.cnf",
            "owner": "mysql",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/mariadb",
            "owner": "mysql:mysql"
        },
        {
            "path": "/backup",
            "owner": "mysql:mysql"
        }
    ]
}
