<?xml version="1.0" encoding="UTF-8"?>
<!--
Copyright (c) 2014 Cisco Systems, Inc. and others. All rights reserved.

This program and the accompanying materials are made available under the
terms of the Eclipse Public License v1.0 which accompanies this distribution,
and is available at http://www.eclipse.org/legal/epl-v10.html
-->
<snapshot>
  <configuration>
    <data xmlns="urn:ietf:params:xml:ns:netconf:base:1.0">
      <modules xmlns="urn:opendaylight:params:xml:ns:yang:controller:config">
        <!-- default OF-switch-connection-provider (port 6633) -->
        <module>
          <type xmlns:rest="urn:opendaylight:params:xml:ns:yang:controller:md:sal:rest:connector">rest:rest-connector-impl</type>
          <name>rest-connector-default-impl</name>
          <websocket-address>{{ hostvars[inventory_hostname]['ansible_' + hostvars[inventory_hostname]['api_interface']]['ipv4']['address'] }}</websocket-address>
          <websocket-port>{{ opendaylight_websocket_port }}</websocket-port>
          <dom-broker>
            <type xmlns:dom="urn:opendaylight:params:xml:ns:yang:controller:md:sal:dom">dom:dom-broker-osgi-registry</type>
            <name>dom-broker</name>
          </dom-broker>
        </module>
      </modules>

      <services xmlns="urn:opendaylight:params:xml:ns:yang:controller:config">
        <service>
          <type xmlns:rest="urn:opendaylight:params:xml:ns:yang:controller:md:sal:rest:connector">rest:rest-connector</type>
          <instance>
            <name>rest-connector-default</name>
            <provider>
              /modules/module[type='rest-connector-impl'][name='rest-connector-default-impl']
            </provider>
          </instance>
        </service>
      </services>
    </data>
  </configuration>
  <required-capabilities>
      <capability>urn:opendaylight:params:xml:ns:yang:controller:md:sal:rest:connector?module=opendaylight-rest-connector&amp;revision=2014-07-24</capability>
  </required-capabilities>
</snapshot>
