[sriov_nic]
# 'physical_device_mappings' is a comma separated list
# Maps a physical network to network inferface used for SRIOV
# "sriovnet1" and tunnel_interface used here as placeholders
# This template should be modified for specific environments
# See Official OpenStack SRIOV documentation for all available options
physical_device_mappings = sriovnet1:{{ tunnel_interface }}
exclude_devices =

[securitygroup]
# Security groups are not supported when using SRIOV, so the firewall
# driver must be disabled.
firewall_driver = neutron.agent.firewall.NoopFirewallDriver
