{
    "command": "neutron-openvswitch-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/ml2/ml2_conf.ini",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/neutron.conf",
            "dest": "/etc/neutron/neutron.conf",
            "owner": "neutron",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ml2_conf.ini",
            "dest": "/etc/neutron/plugins/ml2/ml2_conf.ini",
            "owner": "neutron",
            "perm": "0600"
        },
{% if check_extra_ml2_plugins is defined and check_extra_ml2_plugins.matched > 0 %}{% for plugin in check_extra_ml2_plugins.files %}
        {
            "source": "{{ container_config_directory }}/{{ plugin.path | basename }}",
            "dest": "/etc/neutron/plugins/ml2/{{ plugin.path | basename }}",
            "owner": "neutron",
            "perm": "0600"
        },
{% endfor %}{% endif %}
        {
            "source": "{{ container_config_directory }}/policy.json",
            "dest": "/etc/neutron/policy.json",
            "owner": "neutron",
            "perm": "0600",
            "optional": true
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/neutron",
            "owner": "neutron:neutron",
            "recurse": true
        }
    ]
}
