<aclservice-config xmlns="urn:opendaylight:netvirt:aclservice-config">
  <security-group-mode>{{ opendaylight_acl_impl }}</security-group-mode>
  <default-behavior>deny</default-behavior>
</aclservice-config>
