{
    "command": "start-odl",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/start-odl",
            "dest": "/usr/local/bin/start-odl",
            "owner": "odl",
            "perm": "0655"
        },
        {
            "source": "{{ container_config_directory }}/org.apache.karaf.features.cfg",
            "dest": "/opt/opendaylight/etc/org.apache.karaf.features.cfg",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/org.opendaylight.ovsdb.library.cfg",
            "dest": "/opt/opendaylight/etc/org.opendaylight.ovsdb.library.cfg",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/tomcat-server.xml",
            "dest": "/opt/opendaylight/configuration/tomcat-server.xml",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/jetty.xml",
            "dest": "/opt/opendaylight/etc/jetty.xml",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/org.ops4j.pax.logging.cfg",
            "dest": "/opt/opendaylight/etc/org.ops4j.pax.logging.cfg",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "/var/lib/kolla/config_files/custom.properties",
            "dest": "/opt/opendaylight/etc/custom.properties",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/netvirt-impl-config_netvirt-impl-config.xml",
            "dest": "/opt/opendaylight/etc/opendaylight/datastore/initial/config/netvirt-impl-config_netvirt-impl-config.xml",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/netvirt-aclservice-config.xml",
            "dest": "/opt/opendaylight/etc/opendaylight/datastore/initial/config/netvirt-aclservice-config.xml",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/setenv",
            "dest": "/opt/opendaylight/bin/setenv",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/akka.conf",
            "dest": "/opt/opendaylight/configuration/initial/akka.conf",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/modules.conf",
            "dest": "/opt/opendaylight/configuration/initial/modules.conf",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/module-shards.conf",
            "dest": "/opt/opendaylight/configuration/initial/module-shards.conf",
            "owner": "odl",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/10-rest-connector.xml",
            "dest": "/opt/opendaylight/etc/opendaylight/karaf/10-rest-connector.xml",
            "owner": "odl",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/opendaylight",
            "owner": "odl:odl",
            "recurse": true
        }
    ]
}
