[DEFAULT]
debug = {{ ceilometer_logging_debug }}

log_dir = /var/log/kolla/ceilometer

transport_url = {{ rpc_transport_url }}

{% if nova_compute_virt_type == 'vmware' %}
hypervisor_inspector = vsphere
{% elif nova_compute_virt_type == 'xenapi' %}
hypervisor_inspector = xenapi
{% endif %}

[service_credentials]
auth_url = {{ keystone_internal_url }}/v3
region_name = {{ openstack_region_name }}
password = {{ ceilometer_keystone_password }}
username = {{ ceilometer_keystone_user }}
project_name = service
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
auth_type = password
interface = internal

{% if nova_compute_virt_type == 'vmware' %}
[vmware]
host_ip = {{ vmware_vcenter_host_ip }}
host_username = {{ vmware_vcenter_host_username }}
host_password = {{ vmware_vcenter_host_password }}
insecure = {{ vmware_vcenter_insecure }}
{% if not vmware_vcenter_insecure | bool %}
ca_file = /etc/ceilometer/vmware_ca
{% endif %}
{% endif %}

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}

{% if ceilometer_policy_file is defined %}
[oslo_policy]
policy_file = {{ ceilometer_policy_file }}
{% endif %}

{% if nova_compute_virt_type == 'xenapi' %}
[xenapi]
connection_url = {{ xenserver_connect_protocol }}://{{ xenserver_himn_ip }}
connection_username = {{ xenserver_username }}
connection_password = {{ xenserver_password }}
{% endif %}

[cache]
backend = oslo_cache.memcache_pool
enabled = True
memcache_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}
