[DEFAULT]
debug = {{ blazar_logging_debug }}

log_dir = /var/log/kolla/blazar

transport_url = {{ rpc_transport_url }}

host = {{ api_interface_address }}
port = {{ blazar_api_port }}
os_auth_host = {{ kolla_internal_fqdn }}
os_auth_port = {{ keystone_admin_port }}
os_auth_protocol = {{ admin_protocol }}
os_auth_version = v3
os_admin_username = {{ blazar_keystone_user }}
os_admin_password = {{ blazar_keystone_password }}
os_admin_project_name = service
identity_service = identity

[api]
api_v2_controllers = oshosts,leases

[manager]
plugins = virtual.instance.plugin,physical.host.plugin

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}/v3
auth_url = {{ keystone_admin_url }}/v3
auth_type = password
project_domain_id = default
user_domain_id = default
project_name = service
username = {{ blazar_keystone_user }}
password = {{ blazar_keystone_password }}
service_token_roles_required = True

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[database]
connection = mysql+pymysql://{{ blazar_database_user }}:{{ blazar_database_password }}@{{ blazar_database_address }}/{{ blazar_database_name }}
max_retries = -1

[physical:host]
on_start = on_start
on_end = on_end
aggregate_freepool_name = {{ blazar_aggregate_pool_name }}
blazar_username = {{ blazar_keystone_user }}
blazar_password = {{ blazar_keystone_password }}
blazar_project_name = service

[oslo_messaging_notifications]
{% if enable_ceilometer | bool %}
driver = messagingv2
topics = notifications
{% else %}
driver = noop
{% endif %}

{% if blazar_policy_file is defined %}
[oslo_policy]
policy_file = {{ blazar_policy_file }}
{% endif %}
