{
    "command": "/usr/sbin/chronyd -d -f /etc/chrony/chrony.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/chrony.conf",
            "dest": "/etc/chrony/chrony.conf",
            "owner": "chrony",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/chrony",
            "owner": "chrony:kolla",
            "recurse": true
        },
        {
            "path": "/var/lib/chrony",
            "owner": "chrony:chrony",
            "recurse": true
        }
    ]
}
