{
    "command": "start-ovs",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/start-ovs",
            "dest": "/usr/local/bin/start-ovs",
            "owner": "root",
            "perm": "0655"
        }
    ]
}
