#jinja2: trim_blocks: False
[DEFAULT]
log_dir = /var/log/kolla/panko
debug = {{ panko_logging_debug }}

# Force panko-api.log or will use app.wsgi
log_file = /var/log/kolla/panko/panko-api.log


[database]
{% if panko_database_type == "mongodb" %}
connection = mongodb://{{ panko_database_user }}:{{ panko_database_password }}@{{ panko_database_mongodb_address }}/{{ panko_database_name }}
metering_connection = mongodb://{{ panko_database_user }}:{{ panko_database_password }}@{{ panko_database_mongodb_address }}/{{ panko_database_name }}
{% elif panko_database_type == "mysql" %}
connection = mysql+pymysql://{{ panko_database_user }}:{{ panko_database_password }}@{{ panko_database_mysql_address }}/{{ panko_database_name }}
metering_connection = mysql+pymysql://{{ panko_database_user }}:{{ panko_database_password }}@{{ panko_database_mysql_address }}/{{ panko_database_name }}
{% endif %}

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
project_domain_name = {{ default_project_domain_name }}
project_name = service
user_domain_name = {{ default_user_domain_name }}
username = {{ panko_keystone_user }}
password = {{ panko_keystone_password }}
auth_url = {{ keystone_admin_url }}
auth_type = password

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

{% if panko_policy_file is defined %}
[oslo_policy]
policy_file = {{ panko_policy_file }}
{% endif %}

[oslo_middleware]
enable_proxy_headers_parsing = True
