[DEFAULT]
debug = {{ manila_logging_debug }}

log_dir = /var/log/kolla/manila
use_forwarded_for = true

my_ip = {{ api_interface_address }}

osapi_share_listen = {{ api_interface_address }}
osapi_share_listen_port = {{ manila_api_port }}
osapi_share_workers = {{ openstack_service_workers }}

rootwrap_config = /etc/manila/rootwrap.conf
api_paste_config = /etc/manila/api-paste.ini

enabled_share_protocols = "{{ manila_backends|selectattr('enabled', 'equalto', true)|sum(attribute='protocols', start=[]) | unique | join(',') }}"

auth_strategy = keystone

os_region_name = {{ openstack_region_name }}

transport_url = {{ rpc_transport_url }}

[oslo_concurrency]
lock_path = /var/lib/manila/tmp

[database]
connection = mysql+pymysql://{{ manila_database_user }}:{{ manila_database_password }}@{{ manila_database_address }}/{{ manila_database_name }}
max_retries = -1

[keystone_authtoken]
www_authenticate_uri = {{ keystone_internal_url }}
auth_url = {{ keystone_admin_url }}
auth_type = password
project_domain_id = {{ default_project_domain_id }}
user_domain_id = {{ default_user_domain_id }}
project_name = service
username = {{ manila_keystone_user }}
password = {{ manila_keystone_password }}

memcache_security_strategy = ENCRYPT
memcache_secret_key = {{ memcache_secret_key }}
memcached_servers = {% for host in groups['memcached'] %}{{ hostvars[host]['ansible_' + hostvars[host]['api_interface']]['ipv4']['address'] }}:{{ memcached_port }}{% if not loop.last %},{% endif %}{% endfor %}

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}

[oslo_middleware]
enable_proxy_headers_parsing = True

{% if manila_policy_file is defined %}
[oslo_policy]
policy_file = {{ manila_policy_file }}
{% endif %}
