{
    "command": "heat-api-cfn",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/heat.conf",
            "dest": "/etc/heat/heat.conf",
            "owner": "heat",
            "perm": "0600"
        }{% if heat_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ heat_policy_file }}",
            "dest": "/etc/heat/{{ heat_policy_file }}",
            "owner": "heat",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/heat",
            "owner": "heat:heat",
            "recurse": true
        }
    ]
}
