{
    "command": "octavia-health-manager --config-file /etc/octavia/octavia.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/octavia.conf",
            "dest": "/etc/octavia/octavia.conf",
            "owner": "octavia",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/cakey.pem",
            "dest": "/etc/octavia/certs/private/cakey.pem",
            "owner": "octavia",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ca_01.pem",
            "dest": "/etc/octavia/certs/ca_01.pem",
            "owner": "octavia",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/client.pem",
            "dest": "/etc/octavia/certs/client.pem",
            "owner": "octavia",
            "perm": "0600"
        }
    ]
}
