{
    "command": "/opt/kafka/bin/kafka-server-start.sh /etc/kafka/kafka.server.properties",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/kafka.server.properties",
            "dest": "/etc/kafka/kafka.server.properties",
            "owner": "kafka",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/var/lib/kafka",
            "owner": "kafka:kafka",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/kafka",
            "owner": "kafka:kafka",
            "recurse": true
        }
    ]
}
