{
    "command": "ironic-conductor",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ironic.conf",
            "dest": "/etc/ironic/ironic.conf",
            "owner": "ironic",
            "perm": "0600"
        }{% if ironic_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ ironic_policy_file }}",
            "dest": "/etc/ironic/{{ ironic_policy_file }}",
            "owner": "ironic",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/ironic",
            "owner": "ironic:ironic",
            "recurse": true
        },
        {
            "path": "/var/lib/ironic",
            "owner": "ironic:ironic",
            "recurse": true
        },
        {
            "path": "/tftpboot",
            "owner": "ironic:ironic",
            "recurse": true
        },
        {
            "path": "/httpboot",
            "owner": "ironic:ironic",
            "recurse": true
        }
    ]
}
