{
    "command": "/opt/openstack-exporter/openstack-exporter --os-client-config=/etc/openstack/clouds.yml --web.listen-address={{ api_interface_address }}:{{ prometheus_openstack_exporter_port }} default",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/clouds.yml",
            "dest": "/etc/openstack/clouds.yml",
            "owner": "prometheus",
            "perm": "0600"
        }
    ],
    "permissions": [
        {
            "path": "/data",
            "owner": "prometheus:kolla",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/prometheus",
            "owner": "prometheus:kolla",
            "recurse": true
        }
    ]
}
