{
    "command": "octavia-api --config-file /etc/octavia/octavia.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/octavia.conf",
            "dest": "/etc/octavia/octavia.conf",
            "owner": "octavia",
            "perm": "0600"
        }{% if octavia_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ octavia_policy_file }}",
            "dest": "/etc/octavia/{{ octavia_policy_file }}",
            "owner": "octavia",
            "perm": "0600"
        }{% endif %}
    ]
}
