{
    "command": "/usr/bin/ceph-mds -f -c /etc/ceph/ceph.conf -i {{ inventory_hostname }}",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/ceph.conf",
            "dest": "/etc/ceph/ceph.conf",
            "owner": "ceph",
            "perm": "0600"
        },
        {
            "source": "{{ container_config_directory }}/ceph.mds.{{ inventory_hostname }}.keyring",
            "dest": "/var/lib/ceph/mds/ceph-{{ inventory_hostname }}/keyring",
            "owner": "root",
            "perm": "0644"
        }
    ]
}
