[DEFAULT]
debug = {{ trove_logging_debug }}

log_dir = /var/log/kolla/trove

{% if enable_trove_singletenant | bool %}
nova_proxy_admin_pass = {{ trove_keystone_password }}
nova_proxy_admin_tenant_name = service
nova_proxy_admin_user = trove
remote_nova_client = trove.common.single_tenant_remote.nova_client_trove_admin
remote_cinder_client = trove.common.single_tenant_remote.cinder_client_trove_admin
remote_neutron_client = trove.common.single_tenant_remote.neutron_client_trove_admin
{% endif %}
taskmanager_manager = trove.taskmanager.manager.Manager

transport_url = {{ rpc_transport_url }}

trove_auth_url = {{ keystone_internal_url }}/v3

os_region_name = {{ openstack_region_name }}

nova_compute_endpoint_type = internalURL
neutron_endpoint_type = internalURL
cinder_endpoint_type = internalURL
swift_endpoint_type = internalURL
glance_endpoint_type = internalURL
trove_endpoint_type = internalURL

network_driver = trove.network.neutron.NeutronDriver

network_label_regex = .*

[database]
connection = mysql+pymysql://{{ trove_database_user }}:{{ trove_database_password }}@{{ trove_database_address }}/{{ trove_database_name }}
max_retries = -1

[oslo_messaging_notifications]
transport_url = {{ notify_transport_url }}
{% if enable_ceilometer | bool %}
driver = messagingv2
topics = notifications
{% else %}
driver = noop
{% endif %}

{% if enable_osprofiler | bool %}
[profiler]
enabled = true
trace_sqlalchemy = true
hmac_keys = {{ osprofiler_secret }}
connection_string = {{ osprofiler_backend_connection_string }}
{% endif %}
