#
# Copyright 2016-2017 FUJITSU LIMITED
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

[DEFAULT]
name = main

[composite:main]
use = egg:Paste#urlmap
/: la_version
/healthcheck: la_healthcheck
/v2.0: la_api_v2
/v3.0: la_api_v3

[pipeline:la_version]
pipeline = error_trap versionapp

[pipeline:la_healthcheck]
pipeline = error_trap healthcheckapp

[pipeline:la_api_v2]
pipeline = error_trap request_id auth api_v2_app

[pipeline:la_api_v3]
pipeline = error_trap request_id auth api_v3_app

[app:versionapp]
paste.app_factory = monasca_log_api.app.api:create_version_app

[app:healthcheckapp]
paste.app_factory = monasca_log_api.app.api:create_healthcheck_app

[app:api_v2_app]
paste.app_factory = monasca_log_api.app.api:create_api_app
set api_version=v2.0

[app:api_v3_app]
paste.app_factory = monasca_log_api.app.api:create_api_app
set api_version=v3.0

[filter:auth]
paste.filter_factory = keystonemiddleware.auth_token:filter_factory

[filter:roles]
paste.filter_factory = monasca_log_api.middleware.role_middleware:RoleMiddleware.factory

[filter:request_id]
paste.filter_factory = oslo_middleware.request_id:RequestId.factory

[filter:error_trap]
paste.filter_factory = oslo_middleware.catch_errors:CatchErrors.factory

