[DEFAULT]
name = monasca_api

[pipeline:main]
pipeline = request_id auth api

[app:api]
paste.app_factory = monasca_api.api.server:launch

[filter:auth]
paste.filter_factory = monasca_api.healthcheck.keystone_protocol:filter_factory

[filter:request_id]
paste.filter_factory = oslo_middleware.request_id:RequestId.factory
