[DEFAULT]
log_file = monasca-persister.log
log_dir = /var/log/kolla/monasca
debug = {{ monasca_logging_debug }}

[influxdb]
database_name = {{ monasca_influxdb_name }}
# FIXME(dszumski): This doesn't work with a FQDN so use the VIP directly
ip_address = {{ kolla_internal_vip_address }}
port = {{ monasca_influxdb_http_port }}

[kafka_alarm_history]
uri = {{ monasca_kafka_servers }}
topic = {{ monasca_alarm_state_transitions_topic }}
num_processors = 1

[kafka_metrics]
uri = {{ monasca_kafka_servers }}
topic = {{ monasca_metrics_topic }}
num_processors = {{ monasca_metric_pipeline_threads }}

[zookeeper]
uri = {{ monasca_zookeeper_servers }}
