{
    "command": "watcher-decision-engine --config-file /etc/watcher/watcher.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/watcher.conf",
            "dest": "/etc/watcher/watcher.conf",
            "owner": "watcher",
            "perm": "0600"
        }{% if watcher_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ watcher_policy_file }}",
            "dest": "/etc/watcher/{{ watcher_policy_file }}",
            "owner": "watcher",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/log/kolla/watcher",
            "owner": "watcher:watcher",
            "recurse": true
        }
    ]
}
