{
    "command": "sahara-api --config-file /etc/sahara/sahara.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/sahara.conf",
            "dest": "/etc/sahara/sahara.conf",
            "owner": "sahara",
            "perm": "0600"
        }{% if sahara_policy_file is defined %},
        {
            "source": "{{ container_config_directory }}/{{ sahara_policy_file }}",
            "dest": "/etc/sahara/{{ sahara_policy_file }}",
            "owner": "sahara",
            "perm": "0600"
        }{% endif %}
    ],
    "permissions": [
        {
            "path": "/var/lib/sahara",
            "owner": "sahara:sahara",
            "recurse": true
        },
        {
            "path": "/var/log/kolla/sahara",
            "owner": "sahara:sahara",
            "recurse": true
        }
    ]
}
