# ml2_conf.ini
[DEFAULT]
# Use service_name as the log file name for neutron-openvswitch-agent-xenapi,
# so that it will use a different log file from neutron-openvswitch-agent.
log_file = {{ service_name }}.log
host = {{ os_xenapi_variables.dom0_hostname }}

[agent]
root_helper_daemon = xenapi_root_helper
root_helper =

[ovs]
of_listen_address = {{ os_xenapi_variables.domu_himn_ip }}
ovsdb_connection = tcp:{{ xenserver_himn_ip }}:{{ ovsdb_port }}
{% if computes_need_external_bridge | bool %}
bridge_mappings = {% for interface in neutron_external_interface.split(',') %}physnet{{ loop.index0 + 1 }}:{{ os_xenapi_variables.domu_vifs[interface]["bridge"] }}{% if not loop.last %},{% endif %}{% endfor %}
{% else %}
bridge_mappings =
{% endif %}

local_ip = {% for ip in os_xenapi_variables.dom0_ipv4s %}{% if ip.bridge == os_xenapi_variables.domu_vifs[tunnel_interface]['bridge'] %}{{ip.address}}{% endif %} {% endfor %}

[xenapi]
connection_password = {{ xenserver_password }}
connection_username = {{ xenserver_username }}
connection_url = {{ xenserver_connect_protocol }}://{{ xenserver_himn_ip }}
