[swift]
auth_version = 3
auth_address = {{ openstack_auth.auth_url }}/v3
user = service:{{ glance_keystone_user }}
key = {{ glance_keystone_password }}
project_domain_id = default
user_domain_id = default
