<match *.**>
    type copy
    <store>
       @type monasca
       keystone_url {{ keystone_internal_url }}
       monasca_log_api {{ internal_protocol }}://{{ kolla_internal_fqdn }}:{{ monasca_log_api_port }}
       monasca_log_api_version v3.0
       username {{ monasca_agent_user }}
       password {{ monasca_agent_password }}
       domain_id default
       project_name {{ monasca_control_plane_project }}
       message_field_name Payload
    </store>
</match>
